==> owncloud-10.2.0.zip: owncloud/apps/files_external/l10n/gl.js <==
OC.L10N.register(
    "files_external",
    {
    "Step 1 failed. Exception: %s" : "Fallou o paso 1. Excepción: %s",
    "Step 2 failed. Exception: %s" : "Fallou o paso 2. Excepción: %s",
    "External storage" : "Almacenamento externo",
    "Personal" : "Persoal",
    "System" : "Sistema",
    "Grant access" : "Permitir o acceso",
    "Generate keys" : "Xerar chaves",
    "Error generating key pair" : "Produciuse un erro ao xerar o par de chaves",
    "All users. Type to select user or group." : "Todos os usuarios. Escriba para seleccionar usuario ou grupo.",
    "(group)" : "(grupo)",
    "Saved" : "Gardado",
    "Username" : "Nome de usuario",
    "Password" : "Contrasinal",
    "Save" : "Gardar",
    "Storage with id \"%i\" not found" : "Non se atopa o almacenamento co ID «%i» ",
    "Invalid mount point" : "Punto de montaxe incorrecto",
    "Invalid storage backend \"%s\"" : "Infraestrutura de almacenamento «%s» incorrecta",
    "App key" : "Clave da API",
    "App secret" : "Secreto da aplicación",
    "Client ID" : "ID do cliente",
    "Client secret" : "Secreto do cliente",
    "API key" : "Chave da API",
    "Public key" : "Chave pública",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Bucket",
    "Hostname" : "Nome de máquina",
    "Port" : "Porto",
    "Region" : "Rexión",
    "Enable SSL" : "Activar SSL",
    "Enable Path Style" : "Activar o estilo de ruta",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Subcartafol remoto",
    "Secure https://" : "https:// seguro",
    "Dropbox" : "Dropbox",
    "Local" : "Local",
    "Location" : "Localización",
    "ownCloud" : "ownCloud",
    "Host" : "Servidor",
    "Root" : "Root (raíz)",
    "SFTP with secret key login" : "SFTP con chave secreta de acceso",
    "Share" : "Compartir",
    "SMB / CIFS using OC login" : "SMB / CIFS usando acceso OC",
    "Username as share" : "Nome de usuario como compartición",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "<b>Note:</b> " : "<b>Nota:</b> ",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Nota:</b> A compatibilidade de cURL en PHP non está activada, ou non está instalado. Non é posíbel a montaxe de %s. Consulte co administrador do sistema como instalalo.",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Nota:</b> «%s»  non está instalado. Non é posíbel a montaxe de %s. Consulte co administrador do sistema como instalalo.",
    "No external storage configured" : "Non hai un almacenamento externo configurado",
    "Name" : "Nome",
    "Storage type" : "Tipo de almacenamento",
    "Scope" : "Ámbito",
    "Enable encryption" : "Activar o cifrado",
    "Enable previews" : "Activar as vistas previas",
    "Check for changes" : "Comprobar se hai cambios",
    "Never" : "Nunca",
    "Once every direct access" : "Unha vez cada acceso directo",
    "External Storage" : "Almacenamento externo",
    "Folder name" : "Nome do cartafol",
    "Configuration" : "Configuración",
    "Available for" : "Dispoñíbel para",
    "Add storage" : "Engadir almacenamento",
    "Advanced settings" : "Axustes avanzados",
    "Delete" : "Eliminar",
    "Allow users to mount the following external storage" : "Permitirlle aos usuarios montar o seguinte almacenamento externo",
    "Please provide a valid app key and secret." : "Forneza unha chave de aplicativo e o secreto.",
    "Disabling external storage will unmount all storages for all users, are you sure ?" : "Desactivar o almacenamento externo desmontará todos os almacenamentos para todos os usuarios, está seguro?",
    "Disable external storage" : "Desactivar o almacenamento externo",
    "No URL provided by backend " : " A infraestrutura non forneceu ningún URL",
    "Error getting OAuth2 URL for " : "Produciuse un erro ao obter o URL OAuth2 para ",
    "You can add external storages in the storage settings" : "Pode engadir almacenamento externo nos axustes do almacenamento",
    "Enable external storage" : "Activar o almacenamento externo",
    "External storage has been disabled by the administrator" : "O almacenamento externo foi desactivado polo administrador.",
    "Error configuring OAuth1" : "Produciuse un erro ao configurar OAuth1",
    "Please make sure that the app that provides this backend is installed and enabled" : "Asegúrese de que o aplicativo que fornece esta infraestrutura está instalado e activado ",
    "Admin defined" : "Definido polo administrador",
    "Empty response from the server" : "Resposta baleira do servidor",
    "Couldn't access. Please logout and login to activate this mount point" : "Non é posíbel acceder. Saia e volva acceder para activar este punto de montaxe",
    "Couldn't get the information from the ownCloud server: {code} {type}" : "Non foi posíbel obter a información do servidor ownCloud: {code} {type}",
    "There was an error with message: " : "Produciuse un erro coa mensaxe:",
    "External mount error" : "Produciuse un erro de montaxe externo",
    "Couldn't get the list of Windows network drive mount points: empty response from the server" : "Non é posíbel obter a lista de unidades de rede e os seus puntos de montaxe de Windows: resposta baleira dende o servidor",
    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Algúns dos puntos de montaxe externos configurados non están conectados. Prema na(s) fila(s) vermella(s) para obter máis información",
    "Please enter the credentials for the {mount} mount" : "Insira as credenciais para o punto de montaxe {mount}",
    "Credentials saving failed" : "Non foi posíbel gardar as credenciais",
    "Unsatisfied authentication mechanism parameters" : "Os parámetros do mecanismo de autenticación non son satisfactorios",
    "Tenant name" : "Nome do ocupante",
    "Request timeout (seconds)" : "Tempo de espera da solicitude (segundos)",
    "Allow sharing on user-mounted external storages" : "Permitir a compartición en almacenamentos externos montados polo usuario ",
    "Compatibility with Mac NFD encoding (slow)" : "Compatibilidade coa codificación Mac MFD (lenta)",
    "Couldn't get the list of external mount points: {type}" : "Non foi posíbel obter a lista dos puntos de montaxe externos: {type}",
    "Credentials saved" : "Credenciais gardadas",
    "Credentials required" : "Requírense as credenciais",
    "Invalid backend or authentication mechanism class" : "Clase de mecanismo de autenticación ou infraestrutura incorrecta",
    "Objectstore forbidden" : "Almacén de obxectos non admitido",
    "Unsatisfied backend parameters" : "Os parámetros da infraestrutura non son satisfactorios",
    "Insufficient data: %s" : "Non hai datos abondo: %s",
    "%s" : "%s",
    "OAuth1" : "OAuth1",
    "OAuth2" : "OAuth2",
    "OpenStack" : "OpenStack",
    "Identity endpoint URL" : "URL do punto final de identidade",
    "Rackspace" : "Rackspace",
    "RSA public key" : "Chave pública RSA",
    "SFTP" : "SFTP",
    "SMB / CIFS" : "SMB / CIFS",
    "Domain" : "Dominio:",
    "Service name" : "Nome do servicio",
    "Enable sharing" : "Activar as comparticións",
    "Authentication" : "Autenticación",
    "Allow users to mount external storage" : "Permitirlle aos usuarios montar o almacenamento externo"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.4.0.zip: owncloud/apps/files_external/l10n/gl.js <==
OC.L10N.register(
    "files_external",
    {
    "Step 1 failed. Exception: %s" : "Fallou o paso 1. Excepción: %s",
    "Step 2 failed. Exception: %s" : "Fallou o paso 2. Excepción: %s",
    "External storage" : "Almacenamento externo",
    "Google Drive App Configuration" : "Configuración da aplicación do Gogle Drive",
    "Error verifying OAuth2 Code for " : "Produciuse un erro a verificar o código OAuth2 para",
    "Personal" : "Persoal",
    "System" : "Sistema",
    "Grant access" : "Permitir o acceso",
    "Error configuring OAuth1" : "Produciuse un erro ao configurar OAuth1",
    "Please provide a valid app key and secret." : "Forneza unha chave de aplicación e o secreto.",
    "Generate keys" : "Xerar chaves",
    "Error generating key pair" : "Produciuse un erro ao xerar o par de chaves",
    "All users. Type to select user or group." : "Todos os usuarios. Escriba para seleccionar usuario ou grupo.",
    "(group)" : "(grupo)",
    "Compatibility with Mac NFD encoding (slow)" : "Compatibilidade coa codificación Mac MFD (lenta)",
    "Unknown auth backend \"{b}\"" : "Infraestrutura de autenticación descoñecida «{b}»",
    "Please make sure that the app that provides this backend is installed and enabled" : "Asegúrese de que a aplicación que fornece esta infraestrutura está instalada e activada ",
    "Admin defined" : "Definido polo administrador",
    "Saved" : "Gardado",
    "Disabling external storage will unmount all storages for all users, are you sure ?" : "Desactivar o almacenamento externo desmontará todos os almacenamentos para todos os usuarios, está seguro?",
    "Disable external storage" : "Desactivar o almacenamento externo",
    "No URL provided by backend " : " A infraestrutura non forneceu ningún URL",
    "Error getting OAuth2 URL for " : "Produciuse un erro ao obter o URL OAuth2 para ",
    "Empty response from the server" : "Resposta baleira do servidor",
    "Couldn't access. Please logout and login to activate this mount point" : "Non é posíbel acceder. Saia e volva acceder para activar este punto de montaxe",
    "Couldn't get the information from the ownCloud server: {code} {type}" : "Non foi posíbel obter a información do servidor ownCloud: {code} {type}",
    "Couldn't get the list of external mount points: {type}" : "Non foi posíbel obter a lista dos puntos de montaxe externos: {type}",
    "There was an error with message: " : "Produciuse un erro coa mensaxe:",
    "External mount error" : "Produciuse un erro de montaxe externo",
    "Couldn't get the list of Windows network drive mount points: empty response from the server" : "Non é posíbel obter a lista de unidades de rede e os seus puntos de montaxe de Windows: resposta baleira dende o servidor",
    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Algúns dos puntos de montaxe externos configurados non están conectados. Prema na(s) fila(s) vermella(s) para obter máis información",
    "Please enter the credentials for the {mount} mount" : "Insira as credenciais para o punto de montaxe {mount}",
    "Username" : "Nome de usuario",
    "Password" : "Contrasinal",
    "Credentials saved" : "Credenciais gardadas",
    "Credentials saving failed" : "Non foi posíbel gardar as credenciais",
    "Credentials required" : "Requírense as credenciais",
    "Save" : "Gardar",
    "Storage with id \"%i\" not found" : "Non se atopa o almacenamento co ID «%i» ",
    "Invalid backend or authentication mechanism class" : "Clase de mecanismo de autenticación ou infraestrutura incorrecta",
    "Invalid mount point" : "Punto de montaxe incorrecto",
    "Objectstore forbidden" : "Almacén de obxectos non admitido",
    "Invalid storage backend \"%s\"" : "Infraestrutura de almacenamento «%s» incorrecta",
    "Not permitted to use backend \"%s\"" : "Non está permitido empregar a infraestrutura «%s»",
    "Not permitted to use authentication mechanism \"%s\"" : "Non está permitido empregar o mecanismo de autenticación «%s»",
    "Unsatisfied backend parameters" : "Os parámetros da infraestrutura non son satisfactorios",
    "Unsatisfied authentication mechanism parameters" : "Os parámetros do mecanismo de autenticación non son satisfactorios",
    "Insufficient data: %s" : "Non hai datos abondo: %s",
    "%s" : "%s",
    "Storage with id \"%i\" is not user editable" : "O usuario non pode editar o almacenamento co ID «%i» ",
    "OAuth1" : "OAuth1",
    "App key" : "Clave da API",
    "App secret" : "Secreto da aplicación",
    "OAuth2" : "OAuth2",
    "Client ID" : "ID do cliente",
    "Client secret" : "Secreto do cliente",
    "OpenStack" : "OpenStack",
    "Tenant name" : "Nome do ocupante",
    "Identity endpoint URL" : "URL do punto final de identidade",
    "Rackspace" : "Rackspace",
    "API key" : "Chave da API",
    "RSA public key" : "Chave pública RSA",
    "Public key" : "Chave pública",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Subcartafol remoto",
    "Secure https://" : "https:// seguro",
    "Google Drive" : "Google Drive",
    "Local" : "Local",
    "Location" : "Localización",
    "ownCloud" : "ownCloud",
    "SFTP" : "SFTP",
    "Host" : "Servidor",
    "Root" : "Root (raíz)",
    "SFTP with secret key login" : "SFTP con chave secreta de acceso",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Compartir",
    "Domain" : "Dominio:",
    "SMB / CIFS using OC login" : "SMB / CIFS usando acceso OC",
    "Username as share" : "Nome de usuario como compartición",
    "<b>Note:</b> " : "<b>Nota:</b> ",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Nota:</b> A compatibilidade de cURL en PHP non está activada, ou non está instalado. Non é posíbel a montaxe de %s. Consulte co administrador do sistema como instalalo.",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Nota:</b> «%s»  non está instalado. Non é posíbel a montaxe de %s. Consulte co administrador do sistema como instalalo.",
    "No external storage configured" : "Non hai un almacenamento externo configurado",
    "You can add external storages in the storage settings" : "Pode engadir almacenamento externo nos axustes do almacenamento",
    "Name" : "Nome",
    "Storage type" : "Tipo de almacenamento",
    "Scope" : "Ámbito",
    "Enable encryption" : "Activar o cifrado",
    "Set read-only" : "Estabelecer como de só lectura",
    "Enable previews" : "Activar as vistas previas",
    "Enable sharing" : "Activar as comparticións",
    "Check for changes" : "Comprobar se hai cambios",
    "Never" : "Nunca",
    "Once every direct access" : "Unha vez cada acceso directo",
    "External Storage" : "Almacenamento externo",
    "Enable external storage" : "Activar o almacenamento externo",
    "External storage has been disabled by the administrator" : "O almacenamento externo foi desactivado polo administrador.",
    "Folder name" : "Nome do cartafol",
    "Authentication" : "Autenticación",
    "Configuration" : "Configuración",
    "Available for" : "Dispoñíbel para",
    "Add storage" : "Engadir almacenamento",
    "Advanced settings" : "Axustes avanzados",
    "Delete" : "Eliminar",
    "Allow users to mount external storage" : "Permitirlle aos usuarios montar o almacenamento externo",
    "Allow users to mount the following external storage" : "Permitirlle aos usuarios montar o seguinte almacenamento externo",
    "Allow sharing on user-mounted external storages" : "Permitir a compartición en almacenamentos externos montados polo usuario "
},
"nplurals=2; plural=(n != 1);");
